#!/bin/bash
# Clean up eml files
echo "cleaning nonSpamTest data"
./cleanEml.sh nonSpamTest
echo "cleaning spamTest data"
./cleanEml.sh spamTest
echo "cleaning nonSpamTrain data"
./cleanEml.sh nonSpamTrain
echo "cleaning spamTrain data"
./cleanEml.sh spamTrain
# Create directories
rm -rf naive # delete naive directory
mkdir naive # allocate new naive directory
rm -rf markov # delete markov directory
mkdir markov # allocate new markov directory
rm -rf hyperspace # delete hyperspace directory
mkdir hyperspace # allocate new hyperspace directory
## Copy scripts and CRM114 programs to directories
cp train.sh naive/train.sh
cp classify.sh naive/classify.sh
cp naiveClassify.crm naive/classify.crm
cp naiveTrain.crm naive/train.crm
cp train.sh markov/train.sh
cp classify.sh markov/classify.sh
cp markovClassify.crm markov/classify.crm
cp markovTrain.crm markov/train.crm
cp train.sh hyperspace/train.sh
cp classify.sh hyperspace/classify.sh
cp hyperspaceClassify.crm hyperspace/classify.crm
cp hyperspaceTrain.crm hyperspace/train.crm
# Train classifiers
echo "naive classification: about to build nonSpam statistics. Press CTRL-D to start"
cd naive
./train.sh nonSpamTrain > nonSpamTrain.log
echo "naive classification: about to build spam statistics. Press CTRL-D to start"
./train.sh spamTrain > spamTrain.log
cd ..
cd markov
echo "markov classification: about to build nonSpam statistics. Press CTRL-D to start"
./train.sh nonSpamTrain > nonSpamTrain.log
echo "markov classification: about to build spam statistics. Press CTRL-D to start"
./train.sh spamTrain > spamTrain.log
cd ..
cd hyperspace
echo "hyperspace classification: about to build nonSpam statistics. Press CTRL-D to start"
./train.sh nonSpamTrain > nonSpamTrain.log
echo "hyperspace classification: about to build spam statistics. Press CTRL-D to start"
./train.sh spamTrain > spamTrain.log
cd ..
# Classify test files
cd naive
echo "naive classifying test nonSpam data"
./classify.sh nonSpamTest > nonSpamTest.log
echo "naive classifying test spam data"
./classify.sh spamTest > spamTest.log
cd ..
cd markov
echo "markov classifying test nonSpam data"
./classify.sh nonSpamTest > nonSpamTest.log
echo "markov classifying test spam data"
./classify.sh spamTest > spamTest.log
cd ..
cd hyperspace
echo "hyperspace classifying test nonSpam data"
./classify.sh nonSpamTest > nonSpamTest.log
echo "hyperspace classifying test spam data"
./classify.sh spamTest > spamTest.log
cd ..
echo "summarise classifications"
grep '^test\|^Best' naive/nonSpamTest.log > naiveNonSpam.log
grep '^test\|^Best' naive/spamTest.log > naiveSpam.log
grep '^test\|^Best' markov/nonSpamTest.log > markovNonSpam.log
grep '^test\|^Best' markov/spamTest.log > markovSpam.log
grep '^test\|^Best' hyperspace/nonSpamTest.log > hyperspaceNonSpam.log
grep '^test\|^Best' hyperspace/spamTest.log > hyperspaceSpam.log
# Summary statistics
echo "get classification statistics"
./getstats.sh > stats.log
echo "done"
